==> data-platform-telemetry-0.4.11.jar: META-INF/leiningen/com.signal-ai/data-platform-telemetry/project.clj <==
(def opentelemetry-java-agent-version "0.17.0")

(defproject com.signal-ai/data-platform-telemetry "0.4.11"
  :description "Data Platform Telemetry"
  :url "http://github.com/signal-ai/data-platform-telemetry"
  :license {:name "EPL-2.0 OR GPL-2.0-or-later WITH Classpath-exception-2.0"
            :url "https://www.eclipse.org/legal/epl-2.0/"}
  :dependencies [[org.clojure/clojure "1.11.1" :scope "provided"]
                 [io.prometheus/simpleclient_hotspot "0.16.0"]
                 [clj-commons/iapetos "0.1.13" :exclusions [io.prometheus/simpleclient]]
                 [clojure.java-time "1.0.0"]
                 [circleci/rollcage "1.0.203"]
                 [org.clojure/tools.logging "1.2.4"]
                 [com.github.steffan-westcott/clj-otel-api "0.1.5"]]

  :profiles {:test {:dependencies [[lambdaisland/kaocha "1.70.1086"]
                                   [lambdaisland/kaocha-junit-xml "1.16.98"]
                                   [lambdaisland/kaocha-cloverage "1.0.75"]
                                   [io.opentelemetry.javaagent/opentelemetry-javaagent ~opentelemetry-java-agent-version]]
                    :jvm-opts [~(str "-javaagent:" (System/getenv "HOME") "/.m2/repository/io/opentelemetry/javaagent/opentelemetry-javaagent/" opentelemetry-java-agent-version "/opentelemetry-javaagent-" opentelemetry-java-agent-version ".jar")
                               "-Dotel.javaagent.configuration-file=opentelemetry-config.properties"]}}

  :deploy-repositories [["releases" {:url "https://clojars.org/repo"
                                     :username :env/clojars_username
                                     :password :env/clojars_token
                                     :sign-releases false}]
                        ["snapshots" {:url "https://clojars.org/repo"
                                      :username :env/clojars_username
                                      :password :env/clojars_token}]]
  :aliases {"test" ["with-profile" "dev,test" "run" "-m" "kaocha.runner"]})

==> data-platform-telemetry-0.4.11-20220928.112045-2.jar: META-INF/leiningen/com.signal-ai/data-platform-telemetry/project.clj <==
(def opentelemetry-java-agent-version "0.17.0")

(defproject com.signal-ai/data-platform-telemetry "0.4.11-SNAPSHOT"
  :description "Data Platform Telemetry"
  :url "http://github.com/signal-ai/data-platform-telemetry"
  :license {:name "EPL-2.0 OR GPL-2.0-or-later WITH Classpath-exception-2.0"
            :url "https://www.eclipse.org/legal/epl-2.0/"}
  :dependencies [[org.clojure/clojure "1.11.1" :scope "provided"]
                 [io.prometheus/simpleclient_hotspot "0.16.0"]
                 [clj-commons/iapetos "0.1.13" :exclusions [io.prometheus/simpleclient]]
                 [clojure.java-time "1.0.0"]
                 [circleci/rollcage "1.0.203"]
                 [org.clojure/tools.logging "1.2.4"]
                 [com.github.steffan-westcott/clj-otel-api "0.1.5"]]

  :profiles {:test {:dependencies [[lambdaisland/kaocha "1.70.1086"]
                                   [lambdaisland/kaocha-junit-xml "1.16.98"]
                                   [lambdaisland/kaocha-cloverage "1.0.75"]
                                   [io.opentelemetry.javaagent/opentelemetry-javaagent ~opentelemetry-java-agent-version]]
                    :jvm-opts [~(str "-javaagent:" (System/getenv "HOME") "/.m2/repository/io/opentelemetry/javaagent/opentelemetry-javaagent/" opentelemetry-java-agent-version "/opentelemetry-javaagent-" opentelemetry-java-agent-version ".jar")
                               "-Dotel.javaagent.configuration-file=opentelemetry-config.properties"]}}

  :deploy-repositories [["releases" {:url "https://clojars.org/repo"
                                     :username :env/clojars_username
                                     :password :env/clojars_token
                                     :sign-releases false}]
                        ["snapshots" {:url "https://clojars.org/repo"
                                      :username :env/clojars_username
                                      :password :env/clojars_token}]]
  :aliases {"test" ["with-profile" "dev,test" "run" "-m" "kaocha.runner"]})
